/*  Self_const_par.c 

     To calculate the self-consistent paramete for the blazar emission. 
     
     98/10.10      version 1.0     

           ISAS           Jun Kataoka 

 */

#include <math.h>
#include <stdlib.h>
#include <stdio.h>

#define MAX      2000
#define LIGHT    2.9979e10             /* in cm */
#define HUBBLE   2.430567e-18          /*  s^-1 */


void integ(int, double *, double *, double *);

main()
{

  double l_sync, l_ssc;
  double ita;
  double nu_sync, nu_ssc, nu_brk;
  double t_var, redsft;
  double lumidis;

  double del_1, del_2, del_3, del_4, del_5, del_6, del_7, delta;
  double mag_1, mag_2, mag_3, mag_4, mag;
  double reg_1, reg_2, reg_3, reg_4, reg_5, reg_6, reg, t_crs;
  double esc_1, esc_2, esc_3, esc_4, esc_5, t_esc, velos;
  double gmax_1,gmax_2,gmax_3,gmax,gbrk;


  printf("Let's detemine Multiband  parameters self-consistently!\n");
  printf("You must input 7 observables for the calculation\n");
  printf("\n");

  printf("Energy flux of the Synchrotron peak ? (erg/cm**2/s )");
  scanf("%lf",&l_sync);
  printf("Ratio of Synchrotron-flux vs SSC-flux (l_ssc/l_sync) = ? ");
  scanf("%lf",&ita);
  printf("Maximum frequency of Synchrotron component = ?  (in 10^18 Hz)");
  scanf("%lf",&nu_sync);
  printf("Maximum frequency of SSC component = ?  (in 10^27 Hz)");
  scanf("%lf",&nu_ssc);
  printf("Break frequency of Synchrotron component = ?  (in 10^15.3 Hz)");
  scanf("%lf",&nu_brk);
  printf("Variation time scale in Obs.frame = ?  (in 10^5 sec)");
  scanf("%lf",&t_var);
  printf("red shift : z ? ");
  scanf("%lf",&redsft);  

  printf("\n");
  printf("***** Result******\n");
  printf("\n");

  lumidis = (double)(LIGHT*redsft/HUBBLE) * (1 + 0.25*redsft);

  /*Beaming Factor*/
  del_1  =  (double)2.959e-5; 
  del_2  =  (double)pow(lumidis,0.25); 
  del_3  =  (double)pow(l_sync,0.125); 
  del_4  =  (double)1.0/pow(ita,0.125);
  del_5  =  (double)1.0/pow(nu_sync,0.25); 
  del_6  =  (double)pow(nu_ssc,0.5);
  del_7  =  (double)1.0/pow(t_var,0.25); 
  delta  =  (double)del_1 * del_2 * del_3 * del_4 * del_5 * del_6 * del_7; 

  printf("Beaming Factor : Delta = %e\n", delta);


 /*Magnetic Field*/
  mag_1  =  (double)1.257e-2; 
  mag_2  =  (double)delta; 
  mag_3  =  (double)nu_sync;
  mag_4  =  (double)1.0/(nu_ssc*nu_ssc);
  mag    =  (double)mag_1 * mag_2 * mag_3 * mag_4; 

  printf("Magnetic Field : B = %e (G)\n", mag);

 
  /*Region Size*/
  reg_1  =  (double)2.890e-5; 
  reg_2  =  (double)lumidis;
  reg_3  =  (double)1.0/mag;
  reg_4  =  (double)1.0/(delta*delta); 
  reg_5  =  (double)1.0/pow(ita,0.5);
  reg_6  =  (double)pow(l_sync,0.5);
  reg    =  (double)reg_1 * reg_2 * reg_3 * reg_4 * reg_5 * reg_6;
  t_crs  =  (double)reg/LIGHT; 

  printf("Region Size : R = %e (cm)\n", reg);
  printf("Source Cross Time : T_crs = %e (s)\n",t_crs); 

  /*Escape Time*/  
  esc_1  =  (double)1.909e4;  
  esc_2  =  (double)1.0/pow(mag,1.5);
  esc_3  =  (double)1.0/(1.0 + ita);
  esc_4  =  (double)1.0/pow(nu_brk,0.5);
  esc_5  =  (double)pow(delta,0.5);
  t_esc  =  (double)esc_1 * esc_2 * esc_3 * esc_4 * esc_5;
  velos  =  (double)(reg/t_esc)/LIGHT; 

  printf("Escape Time : T_esc = %e (s)\n", t_esc);
  printf("Mean Electron velocity : V_elec = %e(c)\n",velos); 

  /*Gamma Max*/
  gmax_1  =  (double)8.090e6;
  gmax_2  =  (double)nu_ssc;
  gmax_3  =  (double)1.0/delta;
  gmax    =  (double)gmax_1 * gmax_2 * gmax_3;
  gbrk    =  (double)4.1e4*sqrt(nu_brk)/(sqrt(mag)*sqrt(delta)); 
  printf("Gamma Max: G_max = %e\n", gmax);
  printf("Gamma Brk: G_brk = %e\n", gbrk);

}



