/*  electron_mono.c : for the electron distribution  
                 which radiate synchrotron radiation (single break!)
    Remark!    : You must decide the normalization to meet  
                 observed synchrotron spectrum 
      1998/09/22        
                     ISAS     Jun  Kataoka        
*/

#include <math.h>
#include <stdlib.h>
#include <stdio.h>

#define BIN           50
#define MAX          2000
#define MAXCHR         64
#define RESTENE 8.1871e-7           /* in erg   */ 
#define LIGHT   2.9979e10           /* in cm */
#define PI    3.141592653589793          

void integ(int, double *, double *, double *);

main()
{
  double norm;
  double g_max, g_min;
  double index,ratio;
  double radius,temp,spec; 
  double ened_tot, ened_kin;
  double gm[MAX],N_gm[MAX]; 
  double k_gm[MAX],r_gm[MAX];    
  int i, column;  
  FILE   *fp0; 
  char   file0[MAXCHR]; 

  printf("Input parameters for Electron Distribution\n");

  printf("Normalization : N_0 (electrons/cm^3/ene) = ?  ");
  scanf("%Lf",&norm);
  printf("Gamma_min  = ?  ");
  scanf("%Lf",&g_min);
  printf("Gamma_Max = ?  ");
  scanf("%Lf",&g_max);
  printf("Index = ?  ");
  scanf("%Lf",&spec);
  printf("Source radius (cm) = ?  ");
  scanf("%Lf",&radius);
  printf("Output  Filename?"); 
  scanf("%s",file0);

  if(NULL == (fp0 = fopen(file0,"w"))){
     printf("\n Cannot Open File : %s \n\n", file0);
     exit(1); 
   }

  column = BIN;

  for(i=1; i<=column; i++){
     ratio     = (double)(g_max/g_min);
     index     = (double)i/BIN;
     gm[i]     = (double)g_min*pow(ratio,index);
     temp      = (double)gm[i];
     N_gm[i]   = (double)norm*pow(temp,spec);
     r_gm[i]   = (double)gm[i]*N_gm[i]*RESTENE; 
     k_gm[i]   = (double)(gm[i]-1.0)*N_gm[i]*RESTENE;  

     fprintf(fp0, "%20.15e %20.15e\n", gm[i], N_gm[i]);
   }
     integ(column, gm, r_gm, &ened_tot);      
     integ(column, gm, k_gm, &ened_kin);      
     printf("Total Electron Power in the source frame is\n");

     printf("Energy Density (total) = %e (erg/cm^3)\n ", ened_tot);

     printf("Energy Density (kinetic) = %e (erg/cm^3)\n ", ened_kin);
}


void integ(int clm, double *gma, double *cmp, double *ret)
{
  double sum_K;
  double au1,au2,ad1;
  double bu1,bu2,bu3,bu4,bd1,bd2,bd3;
  double s1,s2,s3;
  double a,b,c;
  int pare;
  int r,u;
  double s[MAX];

  if ((clm%2) == 0){
    pare  = (int)(clm/2 - 1);
  } else { 
    pare  = (int)(clm/2);
  } 
  sum_K = 0.0;
  for(r=0;r<pare; r++){            
      u = (int)2*r;    
      bu1 = (double)(gma[u+1]*gma[u+1] - gma[u+2]*gma[u+2]);
      bu2 = (double)(cmp[u] - cmp[u+1]); 
      bu3 = (double)(gma[u]*gma[u] - gma[u+1]*gma[u+1]);            
      bu4 = (double)(cmp[u+1] - cmp[u+2]);
      bd1 = (double)(gma[u] - gma[u+1]);
      bd2 = (double)(gma[u+1] - gma[u+2]);
      bd3 = (double)(gma[u+2] - gma[u]);
      b   = (double)(bu1*bu2 -bu3*bu4)/(bd1*bd2*bd3) ;
 
      au1 = bu2;
      au2 = bd1;
      ad1 = bu3;
      a   = (double)(au1-b*au2)/ad1;

      c   = (double)cmp[u] - a*gma[u]*gma[u] -b*gma[u];

      s1  = (double)(a/3.0)* (gma[u+2]*gma[u+2]*gma[u+2] 
                                       - gma[u]*gma[u]*gma[u]);  
      s2  = (double)(b/2.0)* (gma[u+2]*gma[u+2] - gma[u]*gma[u]);  
      s3  = (double) c *(gma[u+2] - gma[u]);
      s[r] =(double)(s1+s2+s3);  
      sum_K = sum_K + s[r];     
    }
    if ((clm%2) == 0){
       sum_K = sum_K + (gma[clm-1] - gma[clm-2]) * cmp[clm-2];
    }else{
       ; 
    } 
    *ret = (double)sum_K;
}






